#ifndef GRAPH_HPP__
#define GRAPH_HPP__

#include <iostream>
#include <vector>
#include <string>
#include <unordered_map>
#include "common/json.hpp"
#include "nodes/base/base.hpp"
#include "nodes/stream/streamNode.hpp"
#include "nodes/infer/inferNode.hpp"
#include "nodes/analyze/analyzeNode.hpp"
#include "nodes/draw/drawNode.hpp"
#include "nodes/record/recordNode.hpp"
#include "nodes/httpPush/httpPush.hpp"
#include "nodes/track/trackNode.hpp"


namespace Graph
{

struct PipelineInstance {
    std::string pipeline_id;
    std::string description;
    std::vector<std::shared_ptr<GNode::BaseNode>> nodes; // 只包含此 pipeline 的节点，按顺序
};

class Graph
{

public:
    Graph() = default;
    ~Graph() { }


    // 获取配置好的 pipelines (只读)
    const std::vector<PipelineInstance>& getPipelines() const {
        return configured_pipelines_;
    }

    // 获取加载的共享模型 (只读)
    const std::map<std::string, std::shared_ptr<GNode::Infer>>& getSharedModels() const {
        return shared_models_;
    }


    void create_from_json(const std::string& json_path);

private:
    std::unordered_map<std::string, std::shared_ptr<Infer>> shared_models_;
    std::vector<PipelineInstance> configured_pipelines_;
};

}   // namespace Graph

#endif // GRAPH_HPP__